==> 5.0.tar.gz: laravel-docs/documentation.md <==
- ## Prologue
    - [Release Notes](/docs/{{version}}/releases)
    - [Upgrade Guide](/docs/{{version}}/upgrade)
    - [Contribution Guide](/docs/{{version}}/contributions)
- ## Setup
    - [Installation](/docs/{{version}}/installation)
    - [Configuration](/docs/{{version}}/configuration)
    - [Homestead](/docs/{{version}}/homestead)
- ## The Basics
    - [Routing](/docs/{{version}}/routing)
    - [Middleware](/docs/{{version}}/middleware)
    - [Controllers](/docs/{{version}}/controllers)
    - [Requests](/docs/{{version}}/requests)
    - [Responses](/docs/{{version}}/responses)
    - [Views](/docs/{{version}}/views)
- ## Architecture Foundations
    - [Service Providers](/docs/{{version}}/providers)
    - [Service Container](/docs/{{version}}/container)
    - [Contracts](/docs/{{version}}/contracts)
    - [Facades](/docs/{{version}}/facades)
    - [Request Lifecycle](/docs/{{version}}/lifecycle)
    - [Application Structure](/docs/{{version}}/structure)
- ## Services
    - [Authentication](/docs/{{version}}/authentication)
    - [Billing](/docs/{{version}}/billing)
    - [Cache](/docs/{{version}}/cache)
    - [Collections](/docs/{{version}}/collections)
    - [Command Bus](/docs/{{version}}/bus)
    - [Core Extension](/docs/{{version}}/extending)
    - [Elixir](/docs/{{version}}/elixir)
    - [Encryption](/docs/{{version}}/encryption)
    - [Envoy](/docs/{{version}}/envoy)
    - [Errors & Logging](/docs/{{version}}/errors)
    - [Events](/docs/{{version}}/events)
    - [Filesystem / Cloud Storage](/docs/{{version}}/filesystem)
    - [Hashing](/docs/{{version}}/hashing)
    - [Helpers](/docs/{{version}}/helpers)
    - [Localization](/docs/{{version}}/localization)
    - [Mail](/docs/{{version}}/mail)
    - [Package Development](/docs/{{version}}/packages)
    - [Pagination](/docs/{{version}}/pagination)
    - [Queues](/docs/{{version}}/queues)
    - [Session](/docs/{{version}}/session)
    - [Templates](/docs/{{version}}/templates)
    - [Unit Testing](/docs/{{version}}/testing)
    - [Validation](/docs/{{version}}/validation)
- ## Database
    - [Basic Usage](/docs/{{version}}/database)
    - [Query Builder](/docs/{{version}}/queries)
    - [Eloquent ORM](/docs/{{version}}/eloquent)
    - [Schema Builder](/docs/{{version}}/schema)
    - [Migrations & Seeding](/docs/{{version}}/migrations)
    - [Redis](/docs/{{version}}/redis)
- ## Artisan CLI
    - [Overview](/docs/{{version}}/artisan)
    - [Development](/docs/{{version}}/commands)

==> 5.1.tar.gz: laravel-docs/documentation.md <==
- ## Prologue
    - [Release Notes](/docs/{{version}}/releases)
    - [Upgrade Guide](/docs/{{version}}/upgrade)
    - [Contribution Guide](/docs/{{version}}/contributions)
- ## Setup
    - [Installation](/docs/{{version}}/installation)
    - [Homestead](/docs/{{version}}/homestead)
- ## Tutorials
    - [Beginner Task List](/docs/{{version}}/quickstart)
    - [Intermediate Task List](/docs/{{version}}/quickstart-intermediate)
- ## The Basics
    - [Routing](/docs/{{version}}/routing)
    - [Middleware](/docs/{{version}}/middleware)
    - [Controllers](/docs/{{version}}/controllers)
    - [Requests](/docs/{{version}}/requests)
    - [Responses](/docs/{{version}}/responses)
    - [Views](/docs/{{version}}/views)
    - [Blade Templates](/docs/{{version}}/blade)
- ## Architecture Foundations
    - [Request Lifecycle](/docs/{{version}}/lifecycle)
    - [Application Structure](/docs/{{version}}/structure)
    - [Service Providers](/docs/{{version}}/providers)
    - [Service Container](/docs/{{version}}/container)
    - [Contracts](/docs/{{version}}/contracts)
    - [Facades](/docs/{{version}}/facades)
- ## Services
    - [Authentication](/docs/{{version}}/authentication)
    - [Authorization](/docs/{{version}}/authorization)
    - [Artisan Console](/docs/{{version}}/artisan)
    - [Billing](/docs/{{version}}/billing)
    - [Cache](/docs/{{version}}/cache)
    - [Collections](/docs/{{version}}/collections)
    - [Elixir](/docs/{{version}}/elixir)
    - [Encryption](/docs/{{version}}/encryption)
    - [Errors & Logging](/docs/{{version}}/errors)
    - [Events](/docs/{{version}}/events)
    - [Filesystem / Cloud Storage](/docs/{{version}}/filesystem)
    - [Hashing](/docs/{{version}}/hashing)
    - [Helpers](/docs/{{version}}/helpers)
    - [Localization](/docs/{{version}}/localization)
    - [Mail](/docs/{{version}}/mail)
    - [Package Development](/docs/{{version}}/packages)
    - [Pagination](/docs/{{version}}/pagination)
    - [Queues](/docs/{{version}}/queues)
    - [Redis](/docs/{{version}}/redis)
    - [Session](/docs/{{version}}/session)
    - [SSH Tasks](/docs/{{version}}/envoy)
    - [Task Scheduling](/docs/{{version}}/scheduling)
    - [Testing](/docs/{{version}}/testing)
    - [Validation](/docs/{{version}}/validation)
- ## Database
    - [Getting Started](/docs/{{version}}/database)
    - [Query Builder](/docs/{{version}}/queries)
    - [Migrations](/docs/{{version}}/migrations)
    - [Seeding](/docs/{{version}}/seeding)
- ## Eloquent ORM
    - [Getting Started](/docs/{{version}}/eloquent)
    - [Relationships](/docs/{{version}}/eloquent-relationships)
    - [Collections](/docs/{{version}}/eloquent-collections)
    - [Mutators](/docs/{{version}}/eloquent-mutators)
    - [Serialization](/docs/{{version}}/eloquent-serialization)
